dhg.models
============

Models on Graph
-------------------------

.. autosummary::
   :toctree: ../generated/
   :nosignatures:
   :template: model_template.rst

   dhg.models.GCN
   dhg.models.GraphSAGE 
   dhg.models.GAT
   dhg.models.GIN


Models on Bipartite Graph
-----------------------------

.. autosummary::
   :toctree: ../generated/
   :nosignatures:
   :template: model_template.rst

   dhg.models.NGCF
   dhg.models.LightGCN
   dhg.models.BGNN_Adv
   dhg.models.BGNN_MLP


Models on Hypergraph
------------------------------

.. autosummary::
   :toctree: ../generated/
   :nosignatures:
   :template: model_template.rst

   dhg.models.HGNN
   dhg.models.HGNNP
   dhg.models.HyperGCN
   dhg.models.DHCF
   dhg.models.HNHN
   dhg.models.UniGCN
   dhg.models.UniGAT
   dhg.models.UniSAGE
   dhg.models.UniGIN
